@@ -1,9 +1,12 @@
-#' @rdname detectFronts
-#' @method detectFronts RasterLayer
+#' @rdname getGradients
+#' @method getGradients RasterLayer
 #' @export
-detectFronts.RasterLayer <- function(x, method = "BelkinOReilly2009",
+getGradients.RasterLayer <- function(x, method = "BelkinOReilly2009",
                                      intermediate = FALSE, ...){
 
+  deprecate_warn(when = "as soon as raster package is removed from CRAN",
+                 what = I("raster::RasterLayer method"),
+                 with = I("terra::SpatRaster method"))
   checkArgs_df_RasterLayer(x = x)
 
   # Extract coordinates and data for calculate fronts from Raster and convert to list
@@ -12,8 +15,8 @@ detectFronts.RasterLayer <- function(x, method = "BelkinOReilly2009",
                       y = seq(from = x@extent@ymin, to = x@extent@ymax, length.out = x@nrows),
                       z = matrix(data = startMatrix, nrow = x@ncols))
 
-  allOuts <- detectFronts(x = startMatrix, method = method, intermediate = intermediate,
-                          checkPrevs = FALSE, ...)
+  allOuts <-  getGradients(x = startMatrix, method = method, intermediate = intermediate,
+                           checkPrevs = FALSE, ...)
 
   # Depending on 'intermediate', the output will be a single Raster or a list of them
   if(intermediate){
@@ -32,5 +35,5 @@ detectFronts.RasterLayer <- function(x, method = "BelkinOReilly2009",
     output[] <- as.numeric(allOuts$z)
   }
 
-  return(output)
+  output
 }
